############################################################################
# Matt Rodriguez, LBNL
#Copyright (c) 2003, The Regents of the University of California,
#through Lawrence Berkeley National Laboratory 
#(subject to receipt of any required approvals from the U.S. Dept. of Energy). 
#All rights reserved. 
###########################################################################

import ConfigParser, unittest
from pyGlobus.security import GSSCred, grid_proxy_destroy
from pyGlobus.util import GlobusException
from pyGlobus.security import GSSName
from pyGlobus.security import GSSMechs
from pyGlobus.security import GSSUsage
"""
Unittest for the GSSCred module.
"""

config = None # ConfigParser object

class GSSCredTestCase(unittest.TestCase):
    """
    Test case for the GSSCred module.
    """
    def setUp(self):
        global config
        if config == None:
            config = ConfigParser.ConfigParser()
            config.read("config.txt")
        self._cred = GSSCred()
        self._name = GSSName()
        self._mechs = GSSMechs()
        self._usage = GSSUsage()
        
    def checkGSSCred(self):
        print "\nGSSCredTestCase begin\n"
        try:
            cred = GSSCred()
            del cred
            print "\nGSSCredTestCase completed\n"
        except GlobusException, ex:
            print "Exception occured during testing."
            assert 0, ex.args
        return
    
    def checkAcquireCred(self):
        print "\ncheckAcquireCred"
        print "Make sure you have a valid user proxy before running this test"
        try:
            
            self._cred.acquire_cred(self._name,self._mechs, self._usage)
        except GlobusException, ex:
            print "Exception occured during testing."
            assert 0, ex.args
        
        print "DONE"

    def checkInquireCred(self):
        print "\ncheckInquireCred"
        print "Make sure you have a valid user proxy before running this test"
        try:
            
            self._cred.acquire_cred(self._name,self._mechs, self._usage)
            ret_lifetime, ret_name = self._cred.inquire_cred()
            print "lifetime is: ", ret_lifetime
            n = ret_name.display()
            print "name is: ", n
        except GlobusException, ex:
            print "Exception occured during testing."
            assert 0, ex.args
        
        print "DONE"

    def checkAquireCredLessTimeRequested(self):
        print "\n checkAquireCredLessTimeRequested\n"
        print "Make sure you have a valid user proxy before running this test"
        try:
            time_req = 800
            self._cred.acquire_cred(self._name,self._mechs, self._usage,time_requested=time_req)
            ret_lifetime, ret_name = self._cred.inquire_cred()
            print "lifetime is: ", ret_lifetime
            n = ret_name.display()
            print "name is: ", n
        except GlobusException, ex:
            print "Exception occured during testing."
            assert 0, ex.args
        
        print "DONE"

    def checkExportImportCred(self):
        print "\ncheckExportImportCred"
        print "Make sure you have a valid user proxy before running this test"
        try:
            self._cred.acquire_cred(self._name,self._mechs, self._usage)
            cred_location = self._cred.export_external()
            print "Exported cred to ", cred_location
            newCred = GSSCred()
            newCred.import_external(cred_location)
            ret_lifetime, ret_name = newCred.inquire_cred()
            print "lifetime is: ", ret_lifetime
            print "name is: ", ret_name.display()
            print "destroying exported cred"
	    grid_proxy_destroy(cred_location)
	    print "cred destroyed"
        except GlobusException, ex:
            print "Exception occured during testing."
            assert 0, ex.args
        
        print "DONE"
        
def makeTestSuite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(GSSCredTestCase, "check"))
    return suite

def main():
    unittest.main(defaultTest="makeTestSuite")


if __name__ == "__main__" : main()
    
                  

